require 'package'

class Busybox < Package
  description 'BusyBox combines tiny versions of many common UNIX utilities into a single small executable.'
  homepage 'https://busybox.net/'
  @_ver = '1.33.0'
  version @_ver
  license 'GPL-3'
  compatibility 'all'
  source_url 'https://busybox.net/downloads/busybox-1.33.0.tar.bz2'
  source_sha256 'd568681c91a85edc6710770cebc1e80e042ad74d305b5c2e6d57a5f3de3b8fbd'

  depends_on 'linux_pam'

  def self.patch
    @busyboxconfig = <<~BUSYBOXCONFIGEOF
      #
      # Automatically generated make config: don't edit
      # Busybox version: 1.33.0
      #
      CONFIG_HAVE_DOT_CONFIG=y

      #
      # Settings
      #
      CONFIG_DESKTOP=y
      CONFIG_EXTRA_COMPAT=y
      # CONFIG_FEDORA_COMPAT is not set
      # CONFIG_INCLUDE_SUSv2 is not set
      CONFIG_LONG_OPTS=y
      CONFIG_SHOW_USAGE=y
      CONFIG_FEATURE_VERBOSE_USAGE=y
      CONFIG_FEATURE_COMPRESS_USAGE=y
      CONFIG_LFS=y
      CONFIG_PAM=y
      CONFIG_FEATURE_DEVPTS=y
      # CONFIG_FEATURE_UTMP is not set
      # CONFIG_FEATURE_WTMP is not set
      # CONFIG_FEATURE_PIDFILE is not set
      CONFIG_PID_FILE_PATH="#{CREW_PREFIX}/var/run"
      CONFIG_BUSYBOX=y
      CONFIG_FEATURE_SHOW_SCRIPT=y
      CONFIG_FEATURE_INSTALLER=y
      CONFIG_INSTALL_NO_USR=y
      # CONFIG_FEATURE_SUID is not set
      # CONFIG_FEATURE_SUID_CONFIG is not set
      # CONFIG_FEATURE_SUID_CONFIG_QUIET is not set
      # CONFIG_FEATURE_PREFER_APPLETS is not set
      CONFIG_BUSYBOX_EXEC_PATH="/proc/self/exe"
      # CONFIG_SELINUX is not set
      # CONFIG_FEATURE_CLEAN_UP is not set
      CONFIG_FEATURE_SYSLOG_INFO=y
      CONFIG_FEATURE_SYSLOG=y

      #
      # Build Options
      #
      # CONFIG_STATIC is not set
      # CONFIG_PIE is not set
      # CONFIG_NOMMU is not set
      CONFIG_BUILD_LIBBUSYBOX=y
      # CONFIG_FEATURE_LIBBUSYBOX_STATIC is not set
      CONFIG_FEATURE_INDIVIDUAL=y
      CONFIG_FEATURE_SHARED_BUSYBOX=y
      CONFIG_CROSS_COMPILER_PREFIX=""
      CONFIG_SYSROOT=""
      CONFIG_EXTRA_CFLAGS="-pipe -O2 -fuse-ld=gold -flto=auto -fomit-frame-pointer"
      CONFIG_EXTRA_LDFLAGS="-flto=auto"
      CONFIG_EXTRA_LDLIBS="pthread"
      # CONFIG_USE_PORTABLE_CODE is not set
      # CONFIG_STACK_OPTIMIZATION_386 is not set
      # CONFIG_STATIC_LIBGCC is not set

      #
      # Installation Options ("make install" behavior)
      #
      CONFIG_INSTALL_APPLET_SYMLINKS=y
      # CONFIG_INSTALL_APPLET_HARDLINKS is not set
      # CONFIG_INSTALL_APPLET_SCRIPT_WRAPPERS is not set
      # CONFIG_INSTALL_APPLET_DONT is not set
      # CONFIG_INSTALL_SH_APPLET_SYMLINK is not set
      # CONFIG_INSTALL_SH_APPLET_HARDLINK is not set
      # CONFIG_INSTALL_SH_APPLET_SCRIPT_WRAPPER is not set
      CONFIG_PREFIX="#{CREW_DEST_PREFIX}"

      #
      # Debugging Options
      #
      # CONFIG_DEBUG is not set
      # CONFIG_DEBUG_PESSIMIZE is not set
      # CONFIG_DEBUG_SANITIZE is not set
      # CONFIG_UNIT_TEST is not set
      # CONFIG_WERROR is not set
      # CONFIG_WARN_SIMPLE_MSG is not set
      CONFIG_NO_DEBUG_LIB=y
      # CONFIG_DMALLOC is not set
      # CONFIG_EFENCE is not set

      #
      # Library Tuning
      #
      # CONFIG_FEATURE_USE_BSS_TAIL is not set
      # CONFIG_FLOAT_DURATION is not set
      # CONFIG_FEATURE_RTMINMAX is not set
      # CONFIG_FEATURE_RTMINMAX_USE_LIBC_DEFINITIONS is not set
      CONFIG_FEATURE_BUFFERS_USE_MALLOC=y
      # CONFIG_FEATURE_BUFFERS_GO_ON_STACK is not set
      # CONFIG_FEATURE_BUFFERS_GO_IN_BSS is not set
      CONFIG_PASSWORD_MINLEN=6
      CONFIG_MD5_SMALL=1
      CONFIG_SHA3_SMALL=1
      # CONFIG_FEATURE_FAST_TOP is not set
      # CONFIG_FEATURE_ETC_NETWORKS is not set
      # CONFIG_FEATURE_ETC_SERVICES is not set
      CONFIG_FEATURE_EDITING=y
      CONFIG_FEATURE_EDITING_MAX_LEN=1024
      # CONFIG_FEATURE_EDITING_VI is not set
      CONFIG_FEATURE_EDITING_HISTORY=255
      CONFIG_FEATURE_EDITING_SAVEHISTORY=y
      # CONFIG_FEATURE_EDITING_SAVE_ON_EXIT is not set
      CONFIG_FEATURE_REVERSE_SEARCH=y
      CONFIG_FEATURE_TAB_COMPLETION=y
      CONFIG_FEATURE_USERNAME_COMPLETION=y
      CONFIG_FEATURE_EDITING_FANCY_PROMPT=y
      CONFIG_FEATURE_EDITING_WINCH=y
      CONFIG_FEATURE_EDITING_ASK_TERMINAL=y
      CONFIG_LOCALE_SUPPORT=y
      CONFIG_UNICODE_SUPPORT=y
      # CONFIG_UNICODE_USING_LOCALE is not set
      CONFIG_FEATURE_CHECK_UNICODE_IN_ENV=y
      CONFIG_SUBST_WCHAR=63
      CONFIG_LAST_SUPPORTED_WCHAR=767
      CONFIG_UNICODE_COMBINING_WCHARS=y
      CONFIG_UNICODE_WIDE_WCHARS=y
      CONFIG_UNICODE_BIDI_SUPPORT=y
      # CONFIG_UNICODE_NEUTRAL_TABLE is not set
      # CONFIG_UNICODE_PRESERVE_BROKEN is not set
      CONFIG_FEATURE_NON_POSIX_CP=y
      CONFIG_FEATURE_VERBOSE_CP_MESSAGE=y
      # CONFIG_FEATURE_USE_SENDFILE is not set
      CONFIG_FEATURE_COPYBUF_KB=4
      # CONFIG_FEATURE_SKIP_ROOTFS is not set
      # CONFIG_MONOTONIC_SYSCALL is not set
      # CONFIG_IOCTL_HEX2STR_ERROR is not set
      # CONFIG_FEATURE_HWIB is not set

      #
      # Applets
      #

      #
      # Archival Utilities
      #
      CONFIG_FEATURE_SEAMLESS_XZ=y
      CONFIG_FEATURE_SEAMLESS_LZMA=y
      CONFIG_FEATURE_SEAMLESS_BZ2=y
      CONFIG_FEATURE_SEAMLESS_GZ=y
      CONFIG_FEATURE_SEAMLESS_Z=y
      CONFIG_AR=y
      CONFIG_FEATURE_AR_LONG_FILENAMES=y
      CONFIG_FEATURE_AR_CREATE=y
      CONFIG_UNCOMPRESS=y
      CONFIG_GUNZIP=y
      CONFIG_ZCAT=y
      CONFIG_FEATURE_GUNZIP_LONG_OPTIONS=y
      CONFIG_BUNZIP2=y
      CONFIG_BZCAT=y
      CONFIG_UNLZMA=y
      CONFIG_LZCAT=y
      CONFIG_LZMA=y
      CONFIG_UNXZ=y
      CONFIG_XZCAT=y
      CONFIG_XZ=y
      CONFIG_BZIP2=y
      CONFIG_BZIP2_SMALL=8
      CONFIG_FEATURE_BZIP2_DECOMPRESS=y
      CONFIG_CPIO=y
      CONFIG_FEATURE_CPIO_O=y
      CONFIG_FEATURE_CPIO_P=y
      CONFIG_DPKG=y
      CONFIG_DPKG_DEB=y
      CONFIG_GZIP=y
      CONFIG_FEATURE_GZIP_LONG_OPTIONS=y
      CONFIG_GZIP_FAST=0
      CONFIG_FEATURE_GZIP_LEVELS=y
      CONFIG_FEATURE_GZIP_DECOMPRESS=y
      CONFIG_LZOP=y
      CONFIG_UNLZOP=y
      # CONFIG_LZOPCAT is not set
      CONFIG_LZOP_COMPR_HIGH=y
      CONFIG_RPM=y
      CONFIG_RPM2CPIO=y
      CONFIG_TAR=y
      CONFIG_FEATURE_TAR_LONG_OPTIONS=y
      CONFIG_FEATURE_TAR_CREATE=y
      CONFIG_FEATURE_TAR_AUTODETECT=y
      CONFIG_FEATURE_TAR_FROM=y
      CONFIG_FEATURE_TAR_OLDGNU_COMPATIBILITY=y
      CONFIG_FEATURE_TAR_OLDSUN_COMPATIBILITY=y
      CONFIG_FEATURE_TAR_GNU_EXTENSIONS=y
      CONFIG_FEATURE_TAR_TO_COMMAND=y
      CONFIG_FEATURE_TAR_UNAME_GNAME=y
      CONFIG_FEATURE_TAR_NOPRESERVE_TIME=y
      # CONFIG_FEATURE_TAR_SELINUX is not set
      CONFIG_UNZIP=y
      CONFIG_FEATURE_UNZIP_CDF=y
      CONFIG_FEATURE_UNZIP_BZIP2=y
      CONFIG_FEATURE_UNZIP_LZMA=y
      CONFIG_FEATURE_UNZIP_XZ=y
      CONFIG_FEATURE_LZMA_FAST=y

      #
      # Coreutils
      #
      CONFIG_BASENAME=y
      CONFIG_CAT=y
      CONFIG_FEATURE_CATN=y
      CONFIG_FEATURE_CATV=y
      CONFIG_CHGRP=y
      CONFIG_CHMOD=y
      CONFIG_CHOWN=y
      CONFIG_FEATURE_CHOWN_LONG_OPTIONS=y
      CONFIG_CHROOT=y
      CONFIG_CKSUM=y
      CONFIG_COMM=y
      CONFIG_CP=y
      CONFIG_FEATURE_CP_LONG_OPTIONS=y
      CONFIG_FEATURE_CP_REFLINK=y
      CONFIG_CUT=y
      CONFIG_DATE=y
      CONFIG_FEATURE_DATE_ISOFMT=y
      # CONFIG_FEATURE_DATE_NANO is not set
      CONFIG_FEATURE_DATE_COMPAT=y
      CONFIG_DD=y
      CONFIG_FEATURE_DD_SIGNAL_HANDLING=y
      CONFIG_FEATURE_DD_THIRD_STATUS_LINE=y
      CONFIG_FEATURE_DD_IBS_OBS=y
      CONFIG_FEATURE_DD_STATUS=y
      CONFIG_DF=y
      CONFIG_FEATURE_DF_FANCY=y
      CONFIG_DIRNAME=y
      CONFIG_DOS2UNIX=y
      CONFIG_UNIX2DOS=y
      CONFIG_DU=y
      CONFIG_FEATURE_DU_DEFAULT_BLOCKSIZE_1K=y
      CONFIG_ECHO=y
      CONFIG_FEATURE_FANCY_ECHO=y
      CONFIG_ENV=y
      CONFIG_EXPAND=y
      CONFIG_UNEXPAND=y
      CONFIG_EXPR=y
      CONFIG_EXPR_MATH_SUPPORT_64=y
      CONFIG_FACTOR=y
      CONFIG_FALSE=y
      CONFIG_FOLD=y
      CONFIG_HEAD=y
      CONFIG_FEATURE_FANCY_HEAD=y
      CONFIG_HOSTID=y
      CONFIG_ID=y
      CONFIG_GROUPS=y
      CONFIG_INSTALL=y
      CONFIG_FEATURE_INSTALL_LONG_OPTIONS=y
      CONFIG_LINK=y
      CONFIG_LN=y
      CONFIG_LOGNAME=y
      CONFIG_LS=y
      CONFIG_FEATURE_LS_FILETYPES=y
      CONFIG_FEATURE_LS_FOLLOWLINKS=y
      CONFIG_FEATURE_LS_RECURSIVE=y
      CONFIG_FEATURE_LS_WIDTH=y
      CONFIG_FEATURE_LS_SORTFILES=y
      CONFIG_FEATURE_LS_TIMESTAMPS=y
      CONFIG_FEATURE_LS_USERNAME=y
      CONFIG_FEATURE_LS_COLOR=y
      CONFIG_FEATURE_LS_COLOR_IS_DEFAULT=y
      CONFIG_MD5SUM=y
      CONFIG_SHA1SUM=y
      CONFIG_SHA256SUM=y
      CONFIG_SHA512SUM=y
      CONFIG_SHA3SUM=y

      #
      # Common options for md5sum, sha1sum, sha256sum, sha512sum, sha3sum
      #
      CONFIG_FEATURE_MD5_SHA1_SUM_CHECK=y
      CONFIG_MKDIR=y
      CONFIG_MKFIFO=y
      CONFIG_MKNOD=y
      # CONFIG_MKTEMP is not set
      CONFIG_MV=y
      CONFIG_NICE=y
      CONFIG_NL=y
      CONFIG_NOHUP=y
      CONFIG_NPROC=y
      CONFIG_OD=y
      CONFIG_PASTE=y
      CONFIG_PRINTENV=y
      CONFIG_PRINTF=y
      CONFIG_PWD=y
      CONFIG_READLINK=y
      CONFIG_FEATURE_READLINK_FOLLOW=y
      CONFIG_REALPATH=y
      CONFIG_RM=y
      CONFIG_RMDIR=y
      CONFIG_SEQ=y
      CONFIG_SHRED=y
      CONFIG_SHUF=y
      CONFIG_SLEEP=y
      CONFIG_FEATURE_FANCY_SLEEP=y
      CONFIG_SORT=y
      CONFIG_FEATURE_SORT_BIG=y
      CONFIG_FEATURE_SORT_OPTIMIZE_MEMORY=y
      CONFIG_SPLIT=y
      CONFIG_FEATURE_SPLIT_FANCY=y
      CONFIG_STAT=y
      CONFIG_FEATURE_STAT_FORMAT=y
      CONFIG_FEATURE_STAT_FILESYSTEM=y
      CONFIG_STTY=y
      CONFIG_SUM=y
      CONFIG_SYNC=y
      CONFIG_FEATURE_SYNC_FANCY=y
      CONFIG_FSYNC=y
      CONFIG_TAC=y
      CONFIG_TAIL=y
      CONFIG_FEATURE_FANCY_TAIL=y
      CONFIG_TEE=y
      CONFIG_FEATURE_TEE_USE_BLOCK_IO=y
      CONFIG_TEST=y
      CONFIG_TEST1=y
      CONFIG_TEST2=y
      CONFIG_FEATURE_TEST_64=y
      CONFIG_TIMEOUT=y
      CONFIG_TOUCH=y
      CONFIG_FEATURE_TOUCH_NODEREF=y
      CONFIG_FEATURE_TOUCH_SUSV3=y
      CONFIG_TR=y
      CONFIG_FEATURE_TR_CLASSES=y
      CONFIG_FEATURE_TR_EQUIV=y
      CONFIG_TRUE=y
      CONFIG_TRUNCATE=y
      CONFIG_TTY=y
      CONFIG_UNAME=y
      CONFIG_UNAME_OSNAME="GNU/Linux"
      CONFIG_BB_ARCH=y
      CONFIG_UNIQ=y
      CONFIG_UNLINK=y
      CONFIG_USLEEP=y
      CONFIG_UUDECODE=y
      CONFIG_BASE32=y
      CONFIG_BASE64=y
      CONFIG_UUENCODE=y
      CONFIG_WC=y
      CONFIG_FEATURE_WC_LARGE=y
      # CONFIG_WHO is not set
      # CONFIG_W is not set
      # CONFIG_USERS is not set
      CONFIG_WHOAMI=y
      CONFIG_YES=y

      #
      # Common options
      #
      CONFIG_FEATURE_VERBOSE=y

      #
      # Common options for cp and mv
      #
      CONFIG_FEATURE_PRESERVE_HARDLINKS=y

      #
      # Common options for df, du, ls
      #
      CONFIG_FEATURE_HUMAN_READABLE=y

      #
      # Console Utilities
      #
      # CONFIG_CHVT is not set
      # CONFIG_CLEAR is not set
      # CONFIG_DEALLOCVT is not set
      # CONFIG_DUMPKMAP is not set
      # CONFIG_FGCONSOLE is not set
      # CONFIG_KBD_MODE is not set
      # CONFIG_LOADFONT is not set
      # CONFIG_SETFONT is not set
      # CONFIG_FEATURE_SETFONT_TEXTUAL_MAP is not set
      CONFIG_DEFAULT_SETFONT_DIR=""
      # CONFIG_FEATURE_LOADFONT_PSF2 is not set
      # CONFIG_FEATURE_LOADFONT_RAW is not set
      # CONFIG_LOADKMAP is not set
      # CONFIG_OPENVT is not set
      # CONFIG_RESET is not set
      # CONFIG_RESIZE is not set
      # CONFIG_FEATURE_RESIZE_PRINT is not set
      # CONFIG_SETCONSOLE is not set
      # CONFIG_FEATURE_SETCONSOLE_LONG_OPTIONS is not set
      # CONFIG_SETKEYCODES is not set
      # CONFIG_SETLOGCONS is not set
      # CONFIG_SHOWKEY is not set

      #
      # Debian Utilities
      #
      # CONFIG_PIPE_PROGRESS is not set
      # CONFIG_RUN_PARTS is not set
      # CONFIG_FEATURE_RUN_PARTS_LONG_OPTIONS is not set
      # CONFIG_FEATURE_RUN_PARTS_FANCY is not set
      # CONFIG_START_STOP_DAEMON is not set
      # CONFIG_FEATURE_START_STOP_DAEMON_LONG_OPTIONS is not set
      # CONFIG_FEATURE_START_STOP_DAEMON_FANCY is not set
      CONFIG_WHICH=y

      #
      # klibc-utils
      #
      # CONFIG_MINIPS is not set
      # CONFIG_NUKE is not set
      # CONFIG_RESUME is not set
      # CONFIG_RUN_INIT is not set

      #
      # Editors
      #
      CONFIG_AWK=y
      CONFIG_FEATURE_AWK_LIBM=y
      CONFIG_FEATURE_AWK_GNU_EXTENSIONS=y
      CONFIG_CMP=y
      CONFIG_DIFF=y
      CONFIG_FEATURE_DIFF_LONG_OPTIONS=y
      CONFIG_FEATURE_DIFF_DIR=y
      CONFIG_ED=y
      CONFIG_PATCH=y
      CONFIG_SED=y
      CONFIG_VI=y
      CONFIG_FEATURE_VI_MAX_LEN=4096
      # CONFIG_FEATURE_VI_8BIT is not set
      CONFIG_FEATURE_VI_COLON=y
      CONFIG_FEATURE_VI_YANKMARK=y
      CONFIG_FEATURE_VI_SEARCH=y
      CONFIG_FEATURE_VI_REGEX_SEARCH=y
      CONFIG_FEATURE_VI_USE_SIGNALS=y
      CONFIG_FEATURE_VI_DOT_CMD=y
      CONFIG_FEATURE_VI_READONLY=y
      CONFIG_FEATURE_VI_SETOPTS=y
      CONFIG_FEATURE_VI_SET=y
      CONFIG_FEATURE_VI_WIN_RESIZE=y
      CONFIG_FEATURE_VI_ASK_TERMINAL=y
      CONFIG_FEATURE_VI_UNDO=y
      CONFIG_FEATURE_VI_UNDO_QUEUE=y
      CONFIG_FEATURE_VI_UNDO_QUEUE_MAX=256
      CONFIG_FEATURE_ALLOW_EXEC=y

      #
      # Finding Utilities
      #
      CONFIG_FIND=y
      CONFIG_FEATURE_FIND_PRINT0=y
      CONFIG_FEATURE_FIND_MTIME=y
      CONFIG_FEATURE_FIND_MMIN=y
      CONFIG_FEATURE_FIND_PERM=y
      CONFIG_FEATURE_FIND_TYPE=y
      CONFIG_FEATURE_FIND_EXECUTABLE=y
      CONFIG_FEATURE_FIND_XDEV=y
      CONFIG_FEATURE_FIND_MAXDEPTH=y
      CONFIG_FEATURE_FIND_NEWER=y
      CONFIG_FEATURE_FIND_INUM=y
      CONFIG_FEATURE_FIND_EXEC=y
      CONFIG_FEATURE_FIND_EXEC_PLUS=y
      CONFIG_FEATURE_FIND_USER=y
      CONFIG_FEATURE_FIND_GROUP=y
      CONFIG_FEATURE_FIND_NOT=y
      CONFIG_FEATURE_FIND_DEPTH=y
      CONFIG_FEATURE_FIND_PAREN=y
      CONFIG_FEATURE_FIND_SIZE=y
      CONFIG_FEATURE_FIND_PRUNE=y
      CONFIG_FEATURE_FIND_QUIT=y
      CONFIG_FEATURE_FIND_DELETE=y
      CONFIG_FEATURE_FIND_EMPTY=y
      CONFIG_FEATURE_FIND_PATH=y
      CONFIG_FEATURE_FIND_REGEX=y
      # CONFIG_FEATURE_FIND_CONTEXT is not set
      CONFIG_FEATURE_FIND_LINKS=y
      CONFIG_GREP=y
      CONFIG_EGREP=y
      CONFIG_FGREP=y
      CONFIG_FEATURE_GREP_CONTEXT=y
      CONFIG_XARGS=y
      CONFIG_FEATURE_XARGS_SUPPORT_CONFIRMATION=y
      CONFIG_FEATURE_XARGS_SUPPORT_QUOTES=y
      CONFIG_FEATURE_XARGS_SUPPORT_TERMOPT=y
      CONFIG_FEATURE_XARGS_SUPPORT_ZERO_TERM=y
      CONFIG_FEATURE_XARGS_SUPPORT_REPL_STR=y
      CONFIG_FEATURE_XARGS_SUPPORT_PARALLEL=y
      CONFIG_FEATURE_XARGS_SUPPORT_ARGS_FILE=y

      #
      # Init Utilities
      #
      # CONFIG_BOOTCHARTD is not set
      # CONFIG_FEATURE_BOOTCHARTD_BLOATED_HEADER is not set
      # CONFIG_FEATURE_BOOTCHARTD_CONFIG_FILE is not set
      # CONFIG_HALT is not set
      # CONFIG_POWEROFF is not set
      # CONFIG_REBOOT is not set
      # CONFIG_FEATURE_WAIT_FOR_INIT is not set
      # CONFIG_FEATURE_CALL_TELINIT is not set
      CONFIG_TELINIT_PATH=""
      # CONFIG_INIT is not set
      # CONFIG_LINUXRC is not set
      # CONFIG_FEATURE_USE_INITTAB is not set
      # CONFIG_FEATURE_KILL_REMOVED is not set
      CONFIG_FEATURE_KILL_DELAY=0
      # CONFIG_FEATURE_INIT_SCTTY is not set
      # CONFIG_FEATURE_INIT_SYSLOG is not set
      # CONFIG_FEATURE_INIT_QUIET is not set
      # CONFIG_FEATURE_INIT_COREDUMPS is not set
      CONFIG_INIT_TERMINAL_TYPE=""
      # CONFIG_FEATURE_INIT_MODIFY_CMDLINE is not set

      #
      # Login/Password Management Utilities
      #
      # CONFIG_FEATURE_SHADOWPASSWDS is not set
      # CONFIG_USE_BB_PWD_GRP is not set
      # CONFIG_USE_BB_SHADOW is not set
      # CONFIG_USE_BB_CRYPT is not set
      # CONFIG_USE_BB_CRYPT_SHA is not set
      # CONFIG_ADD_SHELL is not set
      # CONFIG_REMOVE_SHELL is not set
      # CONFIG_ADDGROUP is not set
      # CONFIG_FEATURE_ADDUSER_TO_GROUP is not set
      # CONFIG_ADDUSER is not set
      # CONFIG_FEATURE_CHECK_NAMES is not set
      CONFIG_LAST_ID=0
      CONFIG_FIRST_SYSTEM_ID=0
      CONFIG_LAST_SYSTEM_ID=0
      # CONFIG_CHPASSWD is not set
      CONFIG_FEATURE_DEFAULT_PASSWD_ALGO=""
      # CONFIG_CRYPTPW is not set
      # CONFIG_MKPASSWD is not set
      # CONFIG_DELUSER is not set
      # CONFIG_DELGROUP is not set
      # CONFIG_FEATURE_DEL_USER_FROM_GROUP is not set
      # CONFIG_GETTY is not set
      # CONFIG_LOGIN is not set
      # CONFIG_LOGIN_SESSION_AS_CHILD is not set
      # CONFIG_LOGIN_SCRIPTS is not set
      # CONFIG_FEATURE_NOLOGIN is not set
      # CONFIG_FEATURE_SECURETTY is not set
      # CONFIG_PASSWD is not set
      # CONFIG_FEATURE_PASSWD_WEAK_CHECK is not set
      # CONFIG_SU is not set
      # CONFIG_FEATURE_SU_SYSLOG is not set
      # CONFIG_FEATURE_SU_CHECKS_SHELLS is not set
      # CONFIG_FEATURE_SU_BLANK_PW_NEEDS_SECURE_TTY is not set
      # CONFIG_SULOGIN is not set
      # CONFIG_VLOCK is not set

      #
      # Linux Ext2 FS Progs
      #
      CONFIG_CHATTR=y
      CONFIG_FSCK=y
      CONFIG_LSATTR=y
      CONFIG_TUNE2FS=y

      #
      # Linux Module Utilities
      #
      # CONFIG_MODPROBE_SMALL is not set
      CONFIG_DEPMOD=y
      CONFIG_INSMOD=y
      CONFIG_LSMOD=y
      CONFIG_FEATURE_LSMOD_PRETTY_2_6_OUTPUT=y
      CONFIG_MODINFO=y
      CONFIG_MODPROBE=y
      CONFIG_FEATURE_MODPROBE_BLACKLIST=y
      CONFIG_RMMOD=y

      #
      # Options common to multiple modutils
      #
      CONFIG_FEATURE_CMDLINE_MODULE_OPTIONS=y
      # CONFIG_FEATURE_MODPROBE_SMALL_CHECK_ALREADY_LOADED is not set
      # CONFIG_FEATURE_2_4_MODULES is not set
      # CONFIG_FEATURE_INSMOD_VERSION_CHECKING is not set
      # CONFIG_FEATURE_INSMOD_KSYMOOPS_SYMBOLS is not set
      # CONFIG_FEATURE_INSMOD_LOADINKMEM is not set
      # CONFIG_FEATURE_INSMOD_LOAD_MAP is not set
      # CONFIG_FEATURE_INSMOD_LOAD_MAP_FULL is not set
      CONFIG_FEATURE_CHECK_TAINTED_MODULE=y
      # CONFIG_FEATURE_INSMOD_TRY_MMAP is not set
      CONFIG_FEATURE_MODUTILS_ALIAS=y
      CONFIG_FEATURE_MODUTILS_SYMBOLS=y
      CONFIG_DEFAULT_MODULES_DIR="/lib/modules"
      CONFIG_DEFAULT_DEPMOD_FILE="modules.dep"

      #
      # Linux System Utilities
      #
      # CONFIG_ACPID is not set
      # CONFIG_FEATURE_ACPID_COMPAT is not set
      CONFIG_BLKDISCARD=y
      CONFIG_BLKID=y
      CONFIG_FEATURE_BLKID_TYPE=y
      CONFIG_BLOCKDEV=y
      CONFIG_CAL=y
      CONFIG_CHRT=y
      CONFIG_DMESG=y
      CONFIG_FEATURE_DMESG_PRETTY=y
      CONFIG_EJECT=y
      CONFIG_FEATURE_EJECT_SCSI=y
      CONFIG_FALLOCATE=y
      CONFIG_FATATTR=y
      # CONFIG_FBSET is not set
      # CONFIG_FEATURE_FBSET_FANCY is not set
      # CONFIG_FEATURE_FBSET_READMODE is not set
      # CONFIG_FDFORMAT is not set
      CONFIG_FDISK=y
      # CONFIG_FDISK_SUPPORT_LARGE_DISKS is not set
      CONFIG_FEATURE_FDISK_WRITABLE=y
      CONFIG_FEATURE_AIX_LABEL=y
      CONFIG_FEATURE_SGI_LABEL=y
      CONFIG_FEATURE_SUN_LABEL=y
      CONFIG_FEATURE_OSF_LABEL=y
      CONFIG_FEATURE_GPT_LABEL=y
      # CONFIG_FEATURE_FDISK_ADVANCED is not set
      CONFIG_FINDFS=y
      CONFIG_FLOCK=y
      # CONFIG_FDFLUSH is not set
      CONFIG_FREERAMDISK=y
      CONFIG_FSCK_MINIX=y
      CONFIG_FSFREEZE=y
      CONFIG_FSTRIM=y
      CONFIG_GETOPT=y
      CONFIG_FEATURE_GETOPT_LONG=y
      CONFIG_HEXDUMP=y
      # CONFIG_HD is not set
      CONFIG_XXD=y
      # CONFIG_HWCLOCK is not set
      # CONFIG_FEATURE_HWCLOCK_ADJTIME_FHS is not set
      CONFIG_IONICE=y
      CONFIG_IPCRM=y
      CONFIG_IPCS=y
      # CONFIG_LAST is not set
      # CONFIG_FEATURE_LAST_FANCY is not set
      CONFIG_LOSETUP=y
      CONFIG_LSPCI=y
      CONFIG_LSUSB=y
      # CONFIG_MDEV is not set
      # CONFIG_FEATURE_MDEV_CONF is not set
      # CONFIG_FEATURE_MDEV_RENAME is not set
      # CONFIG_FEATURE_MDEV_RENAME_REGEXP is not set
      # CONFIG_FEATURE_MDEV_EXEC is not set
      # CONFIG_FEATURE_MDEV_LOAD_FIRMWARE is not set
      # CONFIG_FEATURE_MDEV_DAEMON is not set
      # CONFIG_MESG is not set
      # CONFIG_FEATURE_MESG_ENABLE_ONLY_GROUP is not set
      CONFIG_MKE2FS=y
      CONFIG_MKFS_EXT2=y
      CONFIG_MKFS_MINIX=y
      CONFIG_FEATURE_MINIX2=y
      CONFIG_MKFS_REISER=y
      CONFIG_MKDOSFS=y
      CONFIG_MKFS_VFAT=y
      CONFIG_MKSWAP=y
      CONFIG_FEATURE_MKSWAP_UUID=y
      CONFIG_MORE=y
      CONFIG_MOUNT=y
      CONFIG_FEATURE_MOUNT_FAKE=y
      CONFIG_FEATURE_MOUNT_VERBOSE=y
      CONFIG_FEATURE_MOUNT_HELPERS=y
      CONFIG_FEATURE_MOUNT_LABEL=y
      # CONFIG_FEATURE_MOUNT_NFS is not set
      CONFIG_FEATURE_MOUNT_CIFS=y
      CONFIG_FEATURE_MOUNT_FLAGS=y
      CONFIG_FEATURE_MOUNT_FSTAB=y
      CONFIG_FEATURE_MOUNT_OTHERTAB=y
      CONFIG_MOUNTPOINT=y
      # CONFIG_NOLOGIN is not set
      # CONFIG_NOLOGIN_DEPENDENCIES is not set
      # CONFIG_NSENTER is not set
      CONFIG_PIVOT_ROOT=y
      CONFIG_RDATE=y
      CONFIG_RDEV=y
      CONFIG_READPROFILE=y
      CONFIG_RENICE=y
      CONFIG_REV=y
      CONFIG_RTCWAKE=y
      CONFIG_SCRIPT=y
      CONFIG_SCRIPTREPLAY=y
      # CONFIG_SETARCH is not set
      # CONFIG_LINUX32 is not set
      # CONFIG_LINUX64 is not set
      CONFIG_SETPRIV=y
      CONFIG_FEATURE_SETPRIV_DUMP=y
      CONFIG_FEATURE_SETPRIV_CAPABILITIES=y
      CONFIG_FEATURE_SETPRIV_CAPABILITY_NAMES=y
      CONFIG_SETSID=y
      CONFIG_SWAPON=y
      CONFIG_FEATURE_SWAPON_DISCARD=y
      CONFIG_FEATURE_SWAPON_PRI=y
      CONFIG_SWAPOFF=y
      CONFIG_FEATURE_SWAPONOFF_LABEL=y
      # CONFIG_SWITCH_ROOT is not set
      CONFIG_TASKSET=y
      CONFIG_FEATURE_TASKSET_FANCY=y
      CONFIG_FEATURE_TASKSET_CPULIST=y
      CONFIG_UEVENT=y
      CONFIG_UMOUNT=y
      CONFIG_FEATURE_UMOUNT_ALL=y
      CONFIG_UNSHARE=y
      # CONFIG_WALL is not set

      #
      # Common options for mount/umount
      #
      CONFIG_FEATURE_MOUNT_LOOP=y
      CONFIG_FEATURE_MOUNT_LOOP_CREATE=y
      # CONFIG_FEATURE_MTAB_SUPPORT is not set
      CONFIG_VOLUMEID=y

      #
      # Filesystem/Volume identification
      #
      CONFIG_FEATURE_VOLUMEID_BCACHE=y
      CONFIG_FEATURE_VOLUMEID_BTRFS=y
      CONFIG_FEATURE_VOLUMEID_CRAMFS=y
      CONFIG_FEATURE_VOLUMEID_EROFS=y
      CONFIG_FEATURE_VOLUMEID_EXFAT=y
      CONFIG_FEATURE_VOLUMEID_EXT=y
      CONFIG_FEATURE_VOLUMEID_F2FS=y
      CONFIG_FEATURE_VOLUMEID_FAT=y
      CONFIG_FEATURE_VOLUMEID_HFS=y
      CONFIG_FEATURE_VOLUMEID_ISO9660=y
      CONFIG_FEATURE_VOLUMEID_JFS=y
      CONFIG_FEATURE_VOLUMEID_LFS=y
      CONFIG_FEATURE_VOLUMEID_LINUXRAID=y
      CONFIG_FEATURE_VOLUMEID_LINUXSWAP=y
      CONFIG_FEATURE_VOLUMEID_LUKS=y
      CONFIG_FEATURE_VOLUMEID_MINIX=y
      CONFIG_FEATURE_VOLUMEID_NILFS=y
      CONFIG_FEATURE_VOLUMEID_NTFS=y
      CONFIG_FEATURE_VOLUMEID_OCFS2=y
      CONFIG_FEATURE_VOLUMEID_REISERFS=y
      CONFIG_FEATURE_VOLUMEID_ROMFS=y
      CONFIG_FEATURE_VOLUMEID_SQUASHFS=y
      CONFIG_FEATURE_VOLUMEID_SYSV=y
      CONFIG_FEATURE_VOLUMEID_UBIFS=y
      CONFIG_FEATURE_VOLUMEID_UDF=y
      CONFIG_FEATURE_VOLUMEID_XFS=y

      #
      # Miscellaneous Utilities
      #
      # CONFIG_ADJTIMEX is not set
      CONFIG_BBCONFIG=y
      CONFIG_FEATURE_COMPRESS_BBCONFIG=y
      CONFIG_BC=y
      CONFIG_DC=y
      CONFIG_FEATURE_DC_BIG=y
      # CONFIG_FEATURE_DC_LIBM is not set
      CONFIG_FEATURE_BC_INTERACTIVE=y
      CONFIG_FEATURE_BC_LONG_OPTIONS=y
      CONFIG_BEEP=y
      CONFIG_FEATURE_BEEP_FREQ=4000
      CONFIG_FEATURE_BEEP_LENGTH_MS=30
      CONFIG_CHAT=y
      CONFIG_FEATURE_CHAT_NOFAIL=y
      # CONFIG_FEATURE_CHAT_TTY_HIFI is not set
      CONFIG_FEATURE_CHAT_IMPLICIT_CR=y
      CONFIG_FEATURE_CHAT_SWALLOW_OPTS=y
      CONFIG_FEATURE_CHAT_SEND_ESCAPES=y
      CONFIG_FEATURE_CHAT_VAR_ABORT_LEN=y
      CONFIG_FEATURE_CHAT_CLR_ABORT=y
      # CONFIG_CONSPY is not set
      CONFIG_CROND=y
      CONFIG_FEATURE_CROND_D=y
      CONFIG_FEATURE_CROND_CALL_SENDMAIL=y
      CONFIG_FEATURE_CROND_SPECIAL_TIMES=y
      CONFIG_FEATURE_CROND_DIR="#{CREW_PREFIX}/var/spool/cron"
      CONFIG_CRONTAB=y
      # CONFIG_DEVFSD is not set
      # CONFIG_DEVFSD_MODLOAD is not set
      # CONFIG_DEVFSD_FG_NP is not set
      # CONFIG_DEVFSD_VERBOSE is not set
      # CONFIG_FEATURE_DEVFS is not set
      CONFIG_DEVMEM=y
      # CONFIG_FBSPLASH is not set
      CONFIG_FLASH_ERASEALL=y
      CONFIG_FLASH_LOCK=y
      CONFIG_FLASH_UNLOCK=y
      CONFIG_FLASHCP=y
      CONFIG_HDPARM=y
      CONFIG_FEATURE_HDPARM_GET_IDENTITY=y
      CONFIG_FEATURE_HDPARM_HDIO_SCAN_HWIF=y
      CONFIG_FEATURE_HDPARM_HDIO_UNREGISTER_HWIF=y
      CONFIG_FEATURE_HDPARM_HDIO_DRIVE_RESET=y
      CONFIG_FEATURE_HDPARM_HDIO_TRISTATE_HWIF=y
      CONFIG_FEATURE_HDPARM_HDIO_GETSET_DMA=y
      CONFIG_HEXEDIT=y
      CONFIG_I2CGET=y
      CONFIG_I2CSET=y
      CONFIG_I2CDUMP=y
      CONFIG_I2CDETECT=y
      CONFIG_I2CTRANSFER=y
      CONFIG_INOTIFYD=y
      CONFIG_LESS=y
      CONFIG_FEATURE_LESS_MAXLINES=9999999
      CONFIG_FEATURE_LESS_BRACKETS=y
      CONFIG_FEATURE_LESS_FLAGS=y
      CONFIG_FEATURE_LESS_TRUNCATE=y
      CONFIG_FEATURE_LESS_MARKS=y
      CONFIG_FEATURE_LESS_REGEXP=y
      CONFIG_FEATURE_LESS_WINCH=y
      CONFIG_FEATURE_LESS_ASK_TERMINAL=y
      CONFIG_FEATURE_LESS_DASHCMD=y
      CONFIG_FEATURE_LESS_LINENUMS=y
      CONFIG_FEATURE_LESS_RAW=y
      CONFIG_FEATURE_LESS_ENV=y
      CONFIG_LSSCSI=y
      CONFIG_MAKEDEVS=y
      # CONFIG_FEATURE_MAKEDEVS_LEAF is not set
      CONFIG_FEATURE_MAKEDEVS_TABLE=y
      CONFIG_MAN=y
      CONFIG_MICROCOM=y
      # CONFIG_MIM is not set
      CONFIG_MT=y
      CONFIG_NANDWRITE=y
      CONFIG_NANDDUMP=y
      CONFIG_PARTPROBE=y
      CONFIG_RAIDAUTORUN=y
      CONFIG_READAHEAD=y
      CONFIG_RFKILL=y
      # CONFIG_RUNLEVEL is not set
      CONFIG_RX=y
      CONFIG_SETFATTR=y
      CONFIG_SETSERIAL=y
      CONFIG_STRINGS=y
      CONFIG_TIME=y
      CONFIG_TS=y
      CONFIG_TTYSIZE=y
      CONFIG_UBIATTACH=y
      CONFIG_UBIDETACH=y
      CONFIG_UBIMKVOL=y
      CONFIG_UBIRMVOL=y
      CONFIG_UBIRSVOL=y
      CONFIG_UBIUPDATEVOL=y
      CONFIG_UBIRENAME=y
      CONFIG_VOLNAME=y
      CONFIG_WATCHDOG=y

      #
      # Networking Utilities
      #
      # CONFIG_FEATURE_IPV6 is not set
      # CONFIG_FEATURE_UNIX_LOCAL is not set
      # CONFIG_FEATURE_PREFER_IPV4_ADDRESS is not set
      # CONFIG_VERBOSE_RESOLUTION_ERRORS is not set
      # CONFIG_FEATURE_TLS_SHA1 is not set
      # CONFIG_ARP is not set
      CONFIG_ARPING=y
      # CONFIG_BRCTL is not set
      # CONFIG_FEATURE_BRCTL_FANCY is not set
      # CONFIG_FEATURE_BRCTL_SHOW is not set
      # CONFIG_DNSD is not set
      # CONFIG_ETHER_WAKE is not set
      CONFIG_FTPD=y
      CONFIG_FEATURE_FTPD_WRITE=y
      CONFIG_FEATURE_FTPD_ACCEPT_BROKEN_LIST=y
      CONFIG_FEATURE_FTPD_AUTHENTICATION=y
      CONFIG_FTPGET=y
      CONFIG_FTPPUT=y
      CONFIG_FEATURE_FTPGETPUT_LONG_OPTIONS=y
      CONFIG_HOSTNAME=y
      CONFIG_DNSDOMAINNAME=y
      # CONFIG_HTTPD is not set
      # CONFIG_FEATURE_HTTPD_RANGES is not set
      # CONFIG_FEATURE_HTTPD_SETUID is not set
      # CONFIG_FEATURE_HTTPD_BASIC_AUTH is not set
      # CONFIG_FEATURE_HTTPD_AUTH_MD5 is not set
      # CONFIG_FEATURE_HTTPD_CGI is not set
      # CONFIG_FEATURE_HTTPD_CONFIG_WITH_SCRIPT_INTERPR is not set
      # CONFIG_FEATURE_HTTPD_SET_REMOTE_PORT_TO_ENV is not set
      # CONFIG_FEATURE_HTTPD_ENCODE_URL_STR is not set
      # CONFIG_FEATURE_HTTPD_ERROR_PAGES is not set
      # CONFIG_FEATURE_HTTPD_PROXY is not set
      # CONFIG_FEATURE_HTTPD_GZIP is not set
      # CONFIG_FEATURE_HTTPD_ETAG is not set
      # CONFIG_FEATURE_HTTPD_LAST_MODIFIED is not set
      # CONFIG_FEATURE_HTTPD_DATE is not set
      # CONFIG_FEATURE_HTTPD_ACL_IP is not set
      CONFIG_IFCONFIG=y
      CONFIG_FEATURE_IFCONFIG_STATUS=y
      CONFIG_FEATURE_IFCONFIG_SLIP=y
      CONFIG_FEATURE_IFCONFIG_MEMSTART_IOADDR_IRQ=y
      CONFIG_FEATURE_IFCONFIG_HW=y
      CONFIG_FEATURE_IFCONFIG_BROADCAST_PLUS=y
      CONFIG_IFENSLAVE=y
      CONFIG_IFPLUGD=y
      CONFIG_IFUP=y
      CONFIG_IFDOWN=y
      CONFIG_IFUPDOWN_IFSTATE_PATH="#{CREW_PREFIX}/var/lib/ifstate"
      CONFIG_FEATURE_IFUPDOWN_IP=y
      CONFIG_FEATURE_IFUPDOWN_IPV4=y
      # CONFIG_FEATURE_IFUPDOWN_IPV6 is not set
      CONFIG_FEATURE_IFUPDOWN_MAPPING=y
      CONFIG_FEATURE_IFUPDOWN_EXTERNAL_DHCP=y
      CONFIG_INETD=y
      CONFIG_FEATURE_INETD_SUPPORT_BUILTIN_ECHO=y
      CONFIG_FEATURE_INETD_SUPPORT_BUILTIN_DISCARD=y
      CONFIG_FEATURE_INETD_SUPPORT_BUILTIN_TIME=y
      CONFIG_FEATURE_INETD_SUPPORT_BUILTIN_DAYTIME=y
      CONFIG_FEATURE_INETD_SUPPORT_BUILTIN_CHARGEN=y
      # CONFIG_FEATURE_INETD_RPC is not set
      CONFIG_IP=y
      CONFIG_IPADDR=y
      CONFIG_IPLINK=y
      CONFIG_IPROUTE=y
      CONFIG_IPTUNNEL=y
      CONFIG_IPRULE=y
      CONFIG_IPNEIGH=y
      CONFIG_FEATURE_IP_ADDRESS=y
      CONFIG_FEATURE_IP_LINK=y
      CONFIG_FEATURE_IP_ROUTE=y
      CONFIG_FEATURE_IP_ROUTE_DIR="#{CREW_PREFIX}/etc/iproute2"
      CONFIG_FEATURE_IP_TUNNEL=y
      CONFIG_FEATURE_IP_RULE=y
      CONFIG_FEATURE_IP_NEIGH=y
      # CONFIG_FEATURE_IP_RARE_PROTOCOLS is not set
      CONFIG_IPCALC=y
      CONFIG_FEATURE_IPCALC_LONG_OPTIONS=y
      CONFIG_FEATURE_IPCALC_FANCY=y
      CONFIG_FAKEIDENTD=y
      CONFIG_NAMEIF=y
      CONFIG_FEATURE_NAMEIF_EXTENDED=y
      CONFIG_NBDCLIENT=y
      CONFIG_NC=y
      CONFIG_NETCAT=y
      CONFIG_NC_SERVER=y
      CONFIG_NC_EXTRA=y
      CONFIG_NC_110_COMPAT=y
      CONFIG_NETSTAT=y
      CONFIG_FEATURE_NETSTAT_WIDE=y
      CONFIG_FEATURE_NETSTAT_PRG=y
      CONFIG_NSLOOKUP=y
      CONFIG_FEATURE_NSLOOKUP_BIG=y
      CONFIG_FEATURE_NSLOOKUP_LONG_OPTIONS=y
      # CONFIG_NTPD is not set
      # CONFIG_FEATURE_NTPD_SERVER is not set
      # CONFIG_FEATURE_NTPD_CONF is not set
      # CONFIG_FEATURE_NTP_AUTH is not set
      CONFIG_PING=y
      # CONFIG_PING6 is not set
      CONFIG_FEATURE_FANCY_PING=y
      CONFIG_PSCAN=y
      CONFIG_ROUTE=y
      CONFIG_SLATTACH=y
      CONFIG_SSL_CLIENT=y
      CONFIG_TC=y
      CONFIG_FEATURE_TC_INGRESS=y
      CONFIG_TCPSVD=y
      CONFIG_UDPSVD=y
      CONFIG_TELNET=y
      CONFIG_FEATURE_TELNET_TTYPE=y
      CONFIG_FEATURE_TELNET_AUTOLOGIN=y
      CONFIG_FEATURE_TELNET_WIDTH=y
      CONFIG_TELNETD=y
      CONFIG_FEATURE_TELNETD_STANDALONE=y
      CONFIG_FEATURE_TELNETD_INETD_WAIT=y
      CONFIG_TFTP=y
      CONFIG_FEATURE_TFTP_PROGRESS_BAR=y
      CONFIG_FEATURE_TFTP_HPA_COMPAT=y
      CONFIG_TFTPD=y
      CONFIG_FEATURE_TFTP_GET=y
      CONFIG_FEATURE_TFTP_PUT=y
      CONFIG_FEATURE_TFTP_BLOCKSIZE=y
      # CONFIG_TFTP_DEBUG is not set
      CONFIG_TLS=y
      CONFIG_TRACEROUTE=y
      # CONFIG_TRACEROUTE6 is not set
      CONFIG_FEATURE_TRACEROUTE_VERBOSE=y
      CONFIG_FEATURE_TRACEROUTE_USE_ICMP=y
      CONFIG_TUNCTL=y
      CONFIG_FEATURE_TUNCTL_UG=y
      CONFIG_VCONFIG=y
      CONFIG_WGET=y
      CONFIG_FEATURE_WGET_LONG_OPTIONS=y
      CONFIG_FEATURE_WGET_STATUSBAR=y
      CONFIG_FEATURE_WGET_AUTHENTICATION=y
      CONFIG_FEATURE_WGET_TIMEOUT=y
      CONFIG_FEATURE_WGET_HTTPS=y
      CONFIG_FEATURE_WGET_OPENSSL=y
      CONFIG_WHOIS=y
      CONFIG_ZCIP=y
      # CONFIG_UDHCPD is not set
      # CONFIG_FEATURE_UDHCPD_BASE_IP_ON_MAC is not set
      # CONFIG_FEATURE_UDHCPD_WRITE_LEASES_EARLY is not set
      CONFIG_DHCPD_LEASES_FILE=""
      # CONFIG_DUMPLEASES is not set
      # CONFIG_DHCPRELAY is not set
      # CONFIG_UDHCPC is not set
      # CONFIG_FEATURE_UDHCPC_ARPING is not set
      # CONFIG_FEATURE_UDHCPC_SANITIZEOPT is not set
      CONFIG_UDHCPC_DEFAULT_SCRIPT=""
      # CONFIG_UDHCPC6 is not set
      # CONFIG_FEATURE_UDHCPC6_RFC3646 is not set
      # CONFIG_FEATURE_UDHCPC6_RFC4704 is not set
      # CONFIG_FEATURE_UDHCPC6_RFC4833 is not set
      # CONFIG_FEATURE_UDHCPC6_RFC5970 is not set
      # CONFIG_FEATURE_UDHCP_PORT is not set
      CONFIG_UDHCP_DEBUG=0
      CONFIG_UDHCPC_SLACK_FOR_BUGGY_SERVERS=0
      # CONFIG_FEATURE_UDHCP_RFC3397 is not set
      # CONFIG_FEATURE_UDHCP_8021Q is not set
      CONFIG_IFUPDOWN_UDHCPC_CMD_OPTIONS="-R -n"

      #
      # Print Utilities
      #
      # CONFIG_LPD is not set
      # CONFIG_LPR is not set
      # CONFIG_LPQ is not set

      #
      # Mail Utilities
      #
      CONFIG_MAKEMIME=y
      CONFIG_POPMAILDIR=y
      CONFIG_FEATURE_POPMAILDIR_DELIVERY=y
      CONFIG_REFORMIME=y
      CONFIG_FEATURE_REFORMIME_COMPAT=y
      CONFIG_SENDMAIL=y
      CONFIG_FEATURE_MIME_CHARSET="us-ascii"

      #
      # Process Utilities
      #
      CONFIG_FREE=y
      CONFIG_FUSER=y
      CONFIG_IOSTAT=y
      CONFIG_KILL=y
      CONFIG_KILLALL=y
      CONFIG_KILLALL5=y
      CONFIG_LSOF=y
      CONFIG_MPSTAT=y
      CONFIG_NMETER=y
      CONFIG_PGREP=y
      CONFIG_PKILL=y
      CONFIG_PIDOF=y
      CONFIG_FEATURE_PIDOF_SINGLE=y
      CONFIG_FEATURE_PIDOF_OMIT=y
      CONFIG_PMAP=y
      CONFIG_POWERTOP=y
      CONFIG_FEATURE_POWERTOP_INTERACTIVE=y
      CONFIG_PS=y
      # CONFIG_FEATURE_PS_WIDE is not set
      # CONFIG_FEATURE_PS_LONG is not set
      CONFIG_FEATURE_PS_TIME=y
      # CONFIG_FEATURE_PS_UNUSUAL_SYSTEMS is not set
      CONFIG_FEATURE_PS_ADDITIONAL_COLUMNS=y
      CONFIG_PSTREE=y
      CONFIG_PWDX=y
      CONFIG_SMEMCAP=y
      CONFIG_BB_SYSCTL=y
      CONFIG_TOP=y
      CONFIG_FEATURE_TOP_INTERACTIVE=y
      CONFIG_FEATURE_TOP_CPU_USAGE_PERCENTAGE=y
      CONFIG_FEATURE_TOP_CPU_GLOBAL_PERCENTS=y
      CONFIG_FEATURE_TOP_SMP_CPU=y
      CONFIG_FEATURE_TOP_DECIMALS=y
      CONFIG_FEATURE_TOP_SMP_PROCESS=y
      CONFIG_FEATURE_TOPMEM=y
      CONFIG_UPTIME=y
      # CONFIG_FEATURE_UPTIME_UTMP_SUPPORT is not set
      CONFIG_WATCH=y
      CONFIG_FEATURE_SHOW_THREADS=y

      #
      # Runit Utilities
      #
      # CONFIG_CHPST is not set
      # CONFIG_SETUIDGID is not set
      # CONFIG_ENVUIDGID is not set
      # CONFIG_ENVDIR is not set
      # CONFIG_SOFTLIMIT is not set
      # CONFIG_RUNSV is not set
      # CONFIG_RUNSVDIR is not set
      # CONFIG_FEATURE_RUNSVDIR_LOG is not set
      # CONFIG_SV is not set
      CONFIG_SV_DEFAULT_SERVICE_DIR=""
      # CONFIG_SVC is not set
      # CONFIG_SVOK is not set
      # CONFIG_SVLOGD is not set
      # CONFIG_CHCON is not set
      # CONFIG_GETENFORCE is not set
      # CONFIG_GETSEBOOL is not set
      # CONFIG_LOAD_POLICY is not set
      # CONFIG_MATCHPATHCON is not set
      # CONFIG_RUNCON is not set
      # CONFIG_SELINUXENABLED is not set
      # CONFIG_SESTATUS is not set
      # CONFIG_SETENFORCE is not set
      # CONFIG_SETFILES is not set
      # CONFIG_FEATURE_SETFILES_CHECK_OPTION is not set
      # CONFIG_RESTORECON is not set
      # CONFIG_SETSEBOOL is not set

      #
      # Shells
      #
      # CONFIG_SH_IS_ASH is not set
      # CONFIG_SH_IS_HUSH is not set
      CONFIG_SH_IS_NONE=y
      # CONFIG_BASH_IS_ASH is not set
      # CONFIG_BASH_IS_HUSH is not set
      CONFIG_BASH_IS_NONE=y
      CONFIG_SHELL_ASH=y
      CONFIG_ASH=y
      # CONFIG_ASH_OPTIMIZE_FOR_SIZE is not set
      # CONFIG_ASH_INTERNAL_GLOB is not set
      CONFIG_ASH_BASH_COMPAT=y
      CONFIG_ASH_BASH_SOURCE_CURDIR=y
      CONFIG_ASH_BASH_NOT_FOUND_HOOK=y
      CONFIG_ASH_JOB_CONTROL=y
      CONFIG_ASH_ALIAS=y
      CONFIG_ASH_RANDOM_SUPPORT=y
      CONFIG_ASH_EXPAND_PRMT=y
      CONFIG_ASH_IDLE_TIMEOUT=y
      CONFIG_ASH_MAIL=y
      # CONFIG_ASH_ECHO is not set
      # CONFIG_ASH_PRINTF is not set
      # CONFIG_ASH_TEST is not set
      CONFIG_ASH_HELP=y
      # CONFIG_ASH_GETOPTS is not set
      # CONFIG_ASH_CMDCMD is not set
      CONFIG_CTTYHACK=y
      CONFIG_HUSH=y
      CONFIG_SHELL_HUSH=y
      CONFIG_HUSH_BASH_COMPAT=y
      CONFIG_HUSH_BRACE_EXPANSION=y
      CONFIG_HUSH_LINENO_VAR=y
      # CONFIG_HUSH_BASH_SOURCE_CURDIR is not set
      CONFIG_HUSH_INTERACTIVE=y
      CONFIG_HUSH_SAVEHISTORY=y
      CONFIG_HUSH_JOB=y
      CONFIG_HUSH_TICK=y
      CONFIG_HUSH_IF=y
      CONFIG_HUSH_LOOPS=y
      CONFIG_HUSH_CASE=y
      CONFIG_HUSH_FUNCTIONS=y
      CONFIG_HUSH_LOCAL=y
      CONFIG_HUSH_RANDOM_SUPPORT=y
      CONFIG_HUSH_MODE_X=y
      CONFIG_HUSH_ECHO=y
      # CONFIG_HUSH_PRINTF is not set
      # CONFIG_HUSH_TEST is not set
      # CONFIG_HUSH_HELP is not set
      CONFIG_HUSH_EXPORT=y
      CONFIG_HUSH_EXPORT_N=y
      # CONFIG_HUSH_READONLY is not set
      CONFIG_HUSH_KILL=y
      # CONFIG_HUSH_WAIT is not set
      # CONFIG_HUSH_COMMAND is not set
      # CONFIG_HUSH_TRAP is not set
      # CONFIG_HUSH_TYPE is not set
      # CONFIG_HUSH_TIMES is not set
      # CONFIG_HUSH_READ is not set
      CONFIG_HUSH_SET=y
      CONFIG_HUSH_UNSET=y
      # CONFIG_HUSH_ULIMIT is not set
      # CONFIG_HUSH_UMASK is not set
      # CONFIG_HUSH_GETOPTS is not set
      # CONFIG_HUSH_MEMLEAK is not set

      #
      # Options common to all shells
      #
      CONFIG_FEATURE_SH_MATH=y
      CONFIG_FEATURE_SH_MATH_64=y
      CONFIG_FEATURE_SH_MATH_BASE=y
      # CONFIG_FEATURE_SH_EXTRA_QUIET is not set
      # CONFIG_FEATURE_SH_STANDALONE is not set
      # CONFIG_FEATURE_SH_NOFORK is not set
      # CONFIG_FEATURE_SH_READ_FRAC is not set
      # CONFIG_FEATURE_SH_HISTFILESIZE is not set
      # CONFIG_FEATURE_SH_EMBEDDED_SCRIPTS is not set

      #
      # System Logging Utilities
      #
      CONFIG_KLOGD=y

      #
      # klogd should not be used together with syslog to kernel printk buffer
      #
      CONFIG_FEATURE_KLOGD_KLOGCTL=y
      CONFIG_LOGGER=y
      CONFIG_LOGREAD=y
      CONFIG_FEATURE_LOGREAD_REDUCED_LOCKING=y
      CONFIG_SYSLOGD=y
      CONFIG_FEATURE_ROTATE_LOGFILE=y
      CONFIG_FEATURE_REMOTE_LOG=y
      CONFIG_FEATURE_SYSLOGD_DUP=y
      CONFIG_FEATURE_SYSLOGD_CFG=y
      CONFIG_FEATURE_SYSLOGD_PRECISE_TIMESTAMPS=y
      CONFIG_FEATURE_SYSLOGD_READ_BUFFER_SIZE=256
      CONFIG_FEATURE_IPC_SYSLOG=y
      CONFIG_FEATURE_IPC_SYSLOG_BUFFER_SIZE=16
      CONFIG_FEATURE_KMSG_SYSLOG=y
    BUSYBOXCONFIGEOF
    IO.write(".config", @busyboxconfig)
  end

  def self.prebuild
    system 'make oldconfig'
  end

  def self.build
    system 'make'
  end

  def self.check
    system 'make check || true'
  end

  def self.install
    system 'make', "DESTDIR=#{CREW_DEST_PREFIX}", 'install'
    FileUtils.mkdir_p "#{CREW_DEST_PREFIX}/libexec/busybox"
    FileUtils.mv "#{CREW_DEST_PREFIX}/bin/", "#{CREW_DEST_PREFIX}/libexec/busybox/"
    FileUtils.mv "#{CREW_DEST_PREFIX}/sbin/", "#{CREW_DEST_PREFIX}/libexec/busybox/"
    FileUtils.mkdir_p "#{CREW_DEST_PREFIX}/bin/"
    FileUtils.mv "#{CREW_DEST_PREFIX}/libexec/busybox/bin/busybox", "#{CREW_DEST_PREFIX}/bin/busybox"
    
    FileUtils.mkdir_p "#{CREW_DEST_PREFIX}/etc/env.d/"
    @busybox_envd = <<~BUSYBOX_ENVD_EOF
      # busybox path configurations
      # Add busybox applets to the path
      export PATH="$PATH:#{CREW_PREFIX}/libexec/busybox/bin"
      # Add administrative applets to the path (uncomment below if you want this)
      #export PATH="$PATH:#{CREW_PREFIX}/libexec/busybox/sbin"
      
      # If you would rather busybox applets have priority over binaries, uncomment below.
      # Be careful with this, it might break things.
      #export PATH="#{CREW_PREFIX}/libexec/busybox/bin:#{CREW_PREFIX}/libexec/busybox/sbin:$PATH"
    BUSYBOX_ENVD_EOF
    IO.write("#{CREW_DEST_PREFIX}/etc/env.d/busybox", @busybox_envd)
  end

  def self.postinstall
    puts
    puts 'Busybox is a binary within the path.'.lightblue
    puts "Busybox applets can be found in #{CREW_PREFIX}/libexec/busybox/".lightblue
    puts
  end
end
